@@ -8,15 +8,15 @@ import (
 	"encoding/json"
 	"errors"
 	"io"
+	"log/slog"
 	"net/http"
 	"sync"
 	"time"
 
-	"github.com/derailed/k9s/internal/config"
-
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/dao"
-	"github.com/rs/zerolog/log"
+	"github.com/derailed/k9s/internal/slogs"
 	"k8s.io/apimachinery/pkg/util/cache"
 )
 
@@ -107,7 +107,7 @@ func (c *ClusterInfo) fetchK9sLatestRev() string {
 
 	latestRev, err := fetchLatestRev()
 	if err != nil {
-		log.Warn().Msgf("k9s latest rev fetch failed %s", err)
+		slog.Warn("k9s latest rev fetch failed", slogs.Error, err)
 	} else {
 		c.cache.Add(k9sLatestRevKey, latestRev, cacheExpiry)
 	}
@@ -206,7 +206,7 @@ func (c *ClusterInfo) fireNoMetaChanged(data ClusterMeta) {
 // Helpers...
 
 func fetchLatestRev() (string, error) {
-	log.Debug().Msgf("Fetching latest k9s rev...")
+	slog.Debug("Fetching latest k9s rev...")
 	ctx, cancel := context.WithTimeout(context.Background(), 3*time.Second)
 	defer cancel()
 
@@ -234,9 +234,9 @@ func fetchLatestRev() (string, error) {
 	}
 
 	if v, ok := m["name"]; ok {
-		log.Debug().Msgf("K9s latest rev: %q", v.(string))
+		slog.Debug("K9s latest rev", slogs.Revision, v.(string))
 		return v.(string), nil
 	}
 
-	return "", errors.New("No version found")
+	return "", errors.New("no version found")
 }
