@@ -113,10 +113,6 @@ var Registry = map[string]ResourceMeta{
 		Renderer:     &render.Service{},
 		TreeRenderer: &xray.Service{},
 	},
-	"v1/events": {
-		DAO:      &dao.Table{},
-		Renderer: &render.Event{},
-	},
 	"v1/serviceaccounts": {
 		Renderer: &render.ServiceAccount{},
 	},
@@ -193,14 +189,4 @@ var Registry = map[string]ResourceMeta{
 	"rbac.authorization.k8s.io/v1/rolebindings": {
 		Renderer: &render.RoleBinding{},
 	},
-
-	// Autoscaling...
-	"autoscaling/v1/horizontalpodautoscalers": {
-		Renderer: &render.HorizontalPodAutoscaler{},
-		DAO:      &dao.Table{},
-	},
-	"autoscaling/v2/horizontalpodautoscalers": {
-		Renderer: &render.HorizontalPodAutoscaler{},
-		DAO:      &dao.Table{},
-	},
 }
