@@ -8,18 +8,19 @@ import (
 	"context"
 	"fmt"
 	"io"
+	"log/slog"
 	"net/http"
 	"os"
 	"path/filepath"
+	"strings"
 	"sync"
 	"time"
 
-	"github.com/derailed/k9s/internal/dao"
-
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config"
+	"github.com/derailed/k9s/internal/config/data"
+	"github.com/derailed/k9s/internal/slogs"
 	"github.com/rakyll/hey/requester"
-	"github.com/rs/zerolog/log"
 )
 
 const (
@@ -29,11 +30,6 @@ const (
 	k9sUA        = "k9s/"
 )
 
-var (
-	// K9sBenchDir directory to store K9s Benchmark files.
-	K9sBenchDir = filepath.Join(os.TempDir(), fmt.Sprintf("k9s-bench-%s", config.MustK9sUser()))
-)
-
 // Benchmark puts a workload under load.
 type Benchmark struct {
 	canceled bool
@@ -63,7 +59,7 @@ func (b *Benchmark) init(base, version string) error {
 		req.SetBasicAuth(b.config.Auth.User, b.config.Auth.Password)
 	}
 	req.Header = b.config.HTTP.Headers
-	log.Debug().Msgf("Benchmarking Request %s", req.URL.String())
+	slog.Debug("Benchmarking Request", slogs.URL, req.URL.String())
 
 	ua := req.UserAgent()
 	if ua == "" {
@@ -77,8 +73,7 @@ func (b *Benchmark) init(base, version string) error {
 	}
 	req.Header.Set("User-Agent", ua)
 
-	log.Debug().Msgf("Using bench config N:%d--C:%d", b.config.N, b.config.C)
-
+	slog.Debug(fmt.Sprintf("Using bench config N:%d--C:%d", b.config.N, b.config.C))
 	b.worker = &requester.Work{
 		Request:     req,
 		RequestBody: []byte(b.config.HTTP.Body),
@@ -111,39 +106,49 @@ func (b *Benchmark) Canceled() bool {
 }
 
 // Run starts a benchmark.
-func (b *Benchmark) Run(cluster string, done func()) {
-	log.Debug().Msgf("Running benchmark on cluster %s", cluster)
+func (b *Benchmark) Run(cluster, context string, done func()) {
+	slog.Debug("Running benchmark",
+		slogs.Cluster, cluster,
+		slogs.Context, context,
+	)
 	buff := new(bytes.Buffer)
 	b.worker.Writer = buff
 	// this call will block until the benchmark is complete or times out.
 	b.worker.Run()
 	b.worker.Stop()
 	if buff.Len() > 0 {
-		if err := b.save(cluster, buff); err != nil {
-			log.Error().Err(err).Msg("Saving Benchmark")
+		if err := b.save(cluster, context, buff); err != nil {
+			slog.Error("Saving Benchmark", slogs.Error, err)
 		}
 	}
 	done()
 }
 
-func (b *Benchmark) save(cluster string, r io.Reader) error {
-	dir := filepath.Join(K9sBenchDir, cluster)
-	if err := os.MkdirAll(dir, 0744); err != nil {
+func (b *Benchmark) save(cluster, context string, r io.Reader) error {
+	ns, n := client.Namespaced(b.config.Name)
+	n = strings.ReplaceAll(n, "|", "_")
+	n = strings.ReplaceAll(n, ":", "_")
+	dir, err := config.EnsureBenchmarksDir(cluster, context)
+	if err != nil {
+		return err
+	}
+	bf := filepath.Join(dir, fmt.Sprintf(benchFmat, ns, n, time.Now().UnixNano()))
+	if err := data.EnsureDirPath(bf, data.DefaultDirMod); err != nil {
 		return err
 	}
 
-	ns, n := client.Namespaced(b.config.Name)
-	file := filepath.Join(dir, fmt.Sprintf(benchFmat, ns, dao.BenchRx.ReplaceAllString(n, "_"), time.Now().UnixNano()))
-	f, err := os.Create(file)
+	f, err := os.Create(bf)
 	if err != nil {
 		return err
 	}
 	defer func() {
 		if e := f.Close(); e != nil {
-			log.Fatal().Err(e).Msg("Bench save")
+			slog.Error("Benchmark file close failed",
+				slogs.Error, e,
+				slogs.Path, bf,
+			)
 		}
 	}()
-
 	if _, err = io.Copy(f, r); err != nil {
 		return err
 	}
