@@ -98,7 +98,7 @@ func (cc ColumnSpecs) Header(rh model1.Header) model1.Header {
 
 	for _, h := range rh {
 		if idx, ok := hh.IndexOf(h.Name, true); ok {
-			hh[idx].Attrs = hh[idx].Attrs.Merge(h.Attrs)
+			hh[idx].Attrs = hh[idx].Merge(h.Attrs)
 			continue
 		}
 		hh = append(hh, h)
@@ -151,7 +151,7 @@ func hydrate(o runtime.Object, cc ColumnSpecs, parsers []*jsonpath.JSONPath, rh
 					Header: cc[idx].Header,
 					Value:  NAValue,
 				}
-				slog.Warn("Unable to find column %s", slogs.Name, cc[idx].Header.Name)
+				slog.Warn("Unable to find custom column", slogs.Name, cc[idx].Header.Name)
 				continue
 			}
 			var v string
