@@ -13,7 +13,7 @@ import (
 	"github.com/derailed/k9s/internal/config/data"
 	"github.com/derailed/k9s/internal/config/mock"
 	"github.com/derailed/k9s/internal/model"
-	"github.com/derailed/k9s/internal/render"
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tcell/v2"
 	"github.com/stretchr/testify/assert"
@@ -21,7 +21,7 @@ import (
 )
 
 func TestSkinnedContext(t *testing.T) {
-	os.Setenv(config.K9sEnvConfigDir, "/tmp/k9s-test")
+	assert.NoError(t, os.Setenv(config.K9sEnvConfigDir, "/tmp/k9s-test"))
 	assert.NoError(t, config.InitLocs())
 	defer assert.NoError(t, os.RemoveAll(config.K9sEnvConfigDir))
 
@@ -47,12 +47,12 @@ func TestSkinnedContext(t *testing.T) {
 	cfg.Config.K9s.UI = config.UI{Skin: "black-and-wtf"}
 	cfg.RefreshStyles(newMockSynchronizer())
 	assert.True(t, cfg.HasSkin())
-	assert.Equal(t, tcell.ColorGhostWhite.TrueColor(), render.StdColor)
-	assert.Equal(t, tcell.ColorWhiteSmoke.TrueColor(), render.ErrColor)
+	assert.Equal(t, tcell.ColorGhostWhite.TrueColor(), model1.StdColor)
+	assert.Equal(t, tcell.ColorWhiteSmoke.TrueColor(), model1.ErrColor)
 }
 
 func TestBenchConfig(t *testing.T) {
-	os.Setenv(config.K9sEnvConfigDir, "/tmp/test-config")
+	assert.NoError(t, os.Setenv(config.K9sEnvConfigDir, "/tmp/test-config"))
 	assert.NoError(t, config.InitLocs())
 	defer assert.NoError(t, os.RemoveAll(config.K9sEnvConfigDir))
 
