@@ -5,12 +5,12 @@ package ui
 
 import (
 	"context"
+	"log/slog"
 
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
-	"github.com/rs/zerolog/log"
 )
 
 const (
@@ -55,7 +55,7 @@ func (f *Flash) StylesChanged(s *config.Styles) {
 
 // Watch watches for flash changes.
 func (f *Flash) Watch(ctx context.Context, c model.FlashChan) {
-	defer log.Debug().Msgf("Flash Watch Canceled!")
+	defer slog.Debug("Flash Watch Canceled!")
 	for {
 		select {
 		case <-ctx.Done():
