@@ -6,11 +6,10 @@ package ui_test
 import (
 	"testing"
 
-	"github.com/derailed/tcell/v2"
-
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/ui"
+	"github.com/derailed/tcell/v2"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -70,7 +69,10 @@ func TestPromptColor(t *testing.T) {
 	app := ui.App{}
 
 	// Make sure to have different values to be sure that the prompt color actually changes depending on its type
-	assert.NotEqual(t, styles.Prompt().Border.DefaultColor.Color(), styles.Prompt().Border.CommandColor.Color())
+	assert.NotEqual(t,
+		styles.Prompt().Border.DefaultColor.Color(),
+		styles.Prompt().Border.CommandColor.Color(),
+	)
 
 	testCases := []struct {
 		kind          model.BufferKind
