@@ -12,7 +12,6 @@ import (
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config"
-	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/k9s/internal/render"
@@ -54,6 +53,9 @@ type Table struct {
 	hasMetrics  bool
 	ctx         context.Context
 	mx          sync.RWMutex
+	readOnly    bool
+	noIcon      bool
+	fullGVR     bool
 }
 
 // NewTable returns a new table view.
@@ -72,6 +74,30 @@ func NewTable(gvr client.GVR) *Table {
 	}
 }
 
+// SetFullGVR toggles full GVR title display.
+func (t *Table) SetFullGVR(b bool) {
+	t.mx.Lock()
+	defer t.mx.Unlock()
+
+	t.fullGVR = b
+}
+
+// SetNoIcon toggles no icon mode.
+func (t *Table) SetNoIcon(b bool) {
+	t.mx.Lock()
+	defer t.mx.Unlock()
+
+	t.noIcon = b
+}
+
+// SetReadOnly toggles read-only mode.
+func (t *Table) SetReadOnly(ro bool) {
+	t.mx.Lock()
+	defer t.mx.Unlock()
+
+	t.readOnly = ro
+}
+
 func (t *Table) setSortCol(sc model1.SortColumn) {
 	t.mx.Lock()
 	defer t.mx.Unlock()
@@ -107,7 +133,8 @@ func (t *Table) getMSort() bool {
 	return t.manualSort
 }
 
-func (t *Table) setViewSetting(vs *config.ViewSetting) bool {
+// SetViewSetting sets custom view config is present.
+func (t *Table) SetViewSetting(vs *config.ViewSetting) bool {
 	t.mx.Lock()
 	defer t.mx.Unlock()
 
@@ -120,7 +147,8 @@ func (t *Table) setViewSetting(vs *config.ViewSetting) bool {
 	return false
 }
 
-func (t *Table) getViewSetting() *config.ViewSetting {
+// GetViewSetting return current view settings if any.
+func (t *Table) GetViewSetting() *config.ViewSetting {
 	t.mx.RLock()
 	defer t.mx.RUnlock()
 
@@ -154,7 +182,7 @@ func (t *Table) GVR() client.GVR { return t.gvr }
 
 // ViewSettingsChanged notifies listener the view configuration changed.
 func (t *Table) ViewSettingsChanged(vs *config.ViewSetting) {
-	if t.setViewSetting(vs) {
+	if t.SetViewSetting(vs) {
 		if vs == nil {
 			if !t.getMSort() && !t.sortCol.IsSet() {
 				t.setSortCol(model1.SortColumn{})
@@ -287,7 +315,7 @@ func (t *Table) doUpdate(data *model1.TableData) *model1.TableData {
 		t.actions.Delete(KeyShiftP)
 	}
 
-	t.setSortCol(data.ComputeSortCol(t.getViewSetting(), t.getSortCol(), t.getMSort()))
+	t.setSortCol(data.ComputeSortCol(t.GetViewSetting(), t.getSortCol(), t.getMSort()))
 
 	return data
 }
@@ -297,17 +325,12 @@ func (t *Table) UpdateUI(cdata, data *model1.TableData) {
 	fg := t.styles.Table().Header.FgColor.Color()
 	bg := t.styles.Table().Header.BgColor.Color()
 
-	var isNamespaced bool
-	if m, err := dao.MetaAccess.MetaFor(t.GVR()); err == nil {
-		isNamespaced = m.Namespaced
-	}
-
 	var col int
 	for _, h := range cdata.Header() {
 		if h.Hide || (!t.wide && h.Wide) {
 			continue
 		}
-		if h.Name == "NAMESPACE" && (!t.GetModel().ClusterWide() || !isNamespaced) {
+		if h.Name == "NAMESPACE" && !t.GetModel().ClusterWide() {
 			continue
 		}
 		if h.MX && !t.hasMetrics {
@@ -333,7 +356,7 @@ func (t *Table) UpdateUI(cdata, data *model1.TableData) {
 			slog.Error("Unable to find original row event", slogs.RowID, re.Row.ID)
 			return true
 		}
-		t.buildRow(row+1, re, ore, cdata.Header(), pads, isNamespaced)
+		t.buildRow(row+1, re, ore, cdata.Header(), pads)
 
 		return true
 	})
@@ -342,7 +365,7 @@ func (t *Table) UpdateUI(cdata, data *model1.TableData) {
 	t.UpdateTitle()
 }
 
-func (t *Table) buildRow(r int, re, ore model1.RowEvent, h model1.Header, pads MaxyPad, isNamespaced bool) {
+func (t *Table) buildRow(r int, re, ore model1.RowEvent, h model1.Header, pads MaxyPad) {
 	color := model1.DefaultColorer
 	if t.colorerFn != nil {
 		color = t.colorerFn
@@ -364,7 +387,7 @@ func (t *Table) buildRow(r int, re, ore model1.RowEvent, h model1.Header, pads M
 			continue
 		}
 
-		if h[c].Name == "NAMESPACE" && (!t.GetModel().ClusterWide() || !isNamespaced) {
+		if h[c].Name == "NAMESPACE" && !t.GetModel().ClusterWide() {
 			continue
 		}
 		if h[c].MX && !t.hasMetrics {
@@ -532,11 +555,20 @@ func (t *Table) styleTitle() string {
 	if t.Extras != "" {
 		ns = t.Extras
 	}
+
+	resource := t.gvr.R()
+	if t.fullGVR {
+		resource = t.gvr.String()
+	}
+
 	var title string
 	if ns == client.ClusterScope {
-		title = SkinTitle(fmt.Sprintf(TitleFmt, t.gvr, render.AsThousands(rc)), t.styles.Frame())
+		title = SkinTitle(fmt.Sprintf(TitleFmt, resource, render.AsThousands(rc)), t.styles.Frame())
 	} else {
-		title = SkinTitle(fmt.Sprintf(NSTitleFmt, t.gvr, ns, render.AsThousands(rc)), t.styles.Frame())
+		title = SkinTitle(fmt.Sprintf(NSTitleFmt, resource, ns, render.AsThousands(rc)), t.styles.Frame())
+	}
+	if ic := ROIndicator(t.readOnly, t.noIcon); ic != "" {
+		title = " " + ic + title
 	}
 
 	buff := t.cmdBuff.GetText()
@@ -552,3 +584,15 @@ func (t *Table) styleTitle() string {
 
 	return title + SkinTitle(fmt.Sprintf(SearchFmt, buff), t.styles.Frame())
 }
+
+// ROIndicator returns an icon showing whether the session is in readonly mode or not.
+func ROIndicator(ro, noIC bool) string {
+	switch {
+	case noIC:
+		return ""
+	case ro:
+		return lockedIC
+	default:
+		return unlockedIC
+	}
+}
