@@ -23,10 +23,10 @@ const (
 	SearchFmt = "<[filter:bg:r]/%s[fg:bg:-]> "
 
 	// NSTitleFmt represents a namespaced view title.
-	NSTitleFmt = "[fg:bg:b] %s([hilite:bg:b]%s[fg:bg:-])[fg:bg:-][[count:bg:b]%s[fg:bg:-]][fg:bg:-] "
+	NSTitleFmt = " [fg:bg:b]%s([hilite:bg:b]%s[fg:bg:-])[fg:bg:-][[count:bg:b]%s[fg:bg:-]][fg:bg:-] "
 
 	// TitleFmt represents a standard view title.
-	TitleFmt = "[fg:bg:b] %s[fg:bg:-][[count:bg:b]%s[fg:bg:-]][fg:bg:-] "
+	TitleFmt = " [fg:bg:b]%s[fg:bg:-][[count:bg:b]%s[fg:bg:-]][fg:bg:-] "
 
 	descIndicator = "↓"
 	ascIndicator  = "↑"
@@ -72,12 +72,12 @@ func SkinTitle(fmat string, style config.Frame) string {
 	if bgColor == config.DefaultColor {
 		bgColor = config.TransparentColor
 	}
-	fmat = strings.Replace(fmat, "[fg:bg", "["+style.Title.FgColor.String()+":"+bgColor.String(), -1)
+	fmat = strings.ReplaceAll(fmat, "[fg:bg", "["+style.Title.FgColor.String()+":"+bgColor.String())
 	fmat = strings.Replace(fmat, "[hilite", "["+style.Title.HighlightColor.String(), 1)
 	fmat = strings.Replace(fmat, "[key", "["+style.Menu.NumKeyColor.String(), 1)
 	fmat = strings.Replace(fmat, "[filter", "["+style.Title.FilterColor.String(), 1)
 	fmat = strings.Replace(fmat, "[count", "["+style.Title.CounterColor.String(), 1)
-	fmat = strings.Replace(fmat, ":bg:", ":"+bgColor.String()+":", -1)
+	fmat = strings.ReplaceAll(fmat, ":bg:", ":"+bgColor.String()+":")
 
 	return fmat
 }
