@@ -91,8 +91,9 @@ func (b *Browser) Init(ctx context.Context) error {
 	if b.App().IsRunning() {
 		b.app.CmdBuff().Reset()
 	}
-	b.Table.SetReadOnly(b.app.Config.IsReadOnly())
-	b.Table.SetNoIcon(b.app.Config.K9s.UI.NoIcons)
+	b.SetReadOnly(b.app.Config.IsReadOnly())
+	b.SetNoIcon(b.app.Config.K9s.UI.NoIcons)
+	b.SetFullGVR(b.app.Config.K9s.UI.UseFullGVRTitle)
 
 	b.bindKeys(b.Actions())
 	for _, f := range b.bindKeysFn {
