@@ -15,6 +15,7 @@ import (
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/k9s/internal/ui"
+	"github.com/derailed/k9s/internal/view/cmd"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
 	"github.com/sahilm/fuzzy"
@@ -61,6 +62,7 @@ func NewLiveView(app *App, title string, m model.ResourceViewer) *LiveView {
 	return &v
 }
 
+func (v *LiveView) SetCommand(*cmd.Interpreter)      {}
 func (v *LiveView) SetFilter(string)                 {}
 func (v *LiveView) SetLabelFilter(map[string]string) {}
 
@@ -153,7 +155,7 @@ func (v *LiveView) bindKeys() {
 		tcell.KeyDelete: ui.NewSharedKeyAction("Erase", v.eraseCmd, false),
 	})
 
-	if !v.app.Config.K9s.IsReadOnly() {
+	if !v.app.Config.IsReadOnly() {
 		v.actions.Add(ui.KeyE, ui.NewKeyAction("Edit", v.editCmd, true))
 	}
 	if v.title == yamlAction {
@@ -290,11 +292,11 @@ func (v *LiveView) toggleFullScreenCmd(evt *tcell.EventKey) *tcell.EventKey {
 func (v *LiveView) setFullScreen(isFullScreen bool) {
 	v.fullScreen = isFullScreen
 	v.SetFullScreen(isFullScreen)
-	v.Box.SetBorder(!isFullScreen)
+	v.SetBorder(!isFullScreen)
 	if isFullScreen {
-		v.Box.SetBorderPadding(0, 0, 0, 0)
+		v.SetBorderPadding(0, 0, 0, 0)
 	} else {
-		v.Box.SetBorderPadding(0, 0, 1, 1)
+		v.SetBorderPadding(0, 0, 1, 1)
 	}
 }
 
