@@ -85,14 +85,14 @@ func BenchmarkLogFlush(b *testing.B) {
 func TestLogAnsi(t *testing.T) {
 	buff := bytes.NewBufferString("")
 	w := tview.ANSIWriter(buff, "white", "black")
-	fmt.Fprintf(w, "[YELLOW] ok")
+	_, _ = fmt.Fprintf(w, "[YELLOW] ok")
 	assert.Equal(t, "[YELLOW] ok", buff.String())
 
 	v := tview.NewTextView()
 	v.SetDynamicColors(true)
 	aw := tview.ANSIWriter(v, "white", "black")
 	s := "[2019-03-27T15:05:15,246][INFO ][o.e.c.r.a.AllocationService] [es-0] Cluster health status changed from [YELLOW] to [GREEN] (reason: [shards started [[.monitoring-es-6-2019.03.27][0]]"
-	fmt.Fprintf(aw, "%s", s)
+	_, _ = fmt.Fprintf(aw, "%s", s)
 	assert.Equal(t, s+"\n", v.GetText(false))
 }
 
