@@ -21,7 +21,7 @@ type ServiceAccount struct {
 // NewServiceAccount returns a new viewer.
 func NewServiceAccount(gvr client.GVR) ResourceViewer {
 	s := ServiceAccount{
-		ResourceViewer: NewBrowser(gvr),
+		ResourceViewer: NewOwnerExtender(NewBrowser(gvr)),
 	}
 	s.AddBindKeysFn(s.bindKeys)
 	s.SetContextFn(s.subjectCtx)
@@ -29,8 +29,8 @@ func NewServiceAccount(gvr client.GVR) ResourceViewer {
 	return &s
 }
 
-func (s *ServiceAccount) bindKeys(aa ui.KeyActions) {
-	aa.Add(ui.KeyActions{
+func (s *ServiceAccount) bindKeys(aa *ui.KeyActions) {
+	aa.Bulk(ui.KeyMap{
 		ui.KeyU:        ui.NewKeyAction("UsedBy", s.refCmd, true),
 		tcell.KeyEnter: ui.NewKeyAction("Rules", s.policyCmd, true),
 	})
