@@ -20,6 +20,7 @@ import (
 	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/k9s/internal/ui/dialog"
+	"github.com/derailed/k9s/internal/view/cmd"
 	"github.com/derailed/k9s/internal/xray"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
@@ -54,6 +55,7 @@ func NewXray(gvr client.GVR) ResourceViewer {
 	}
 }
 
+func (x *Xray) SetCommand(*cmd.Interpreter)      {}
 func (x *Xray) SetFilter(string)                 {}
 func (x *Xray) SetLabelFilter(map[string]string) {}
 
@@ -147,7 +149,7 @@ func (x *Xray) refreshActions() {
 
 	x.Actions().Clear()
 	x.bindKeys()
-	x.Tree.BindKeys()
+	x.BindKeys()
 
 	spec := x.selectedSpec()
 	if spec == nil {
@@ -675,6 +677,9 @@ func (x *Xray) styleTitle() string {
 	} else {
 		title = ui.SkinTitle(fmt.Sprintf(ui.NSTitleFmt, base, ns, render.AsThousands(int64(x.Count))), x.app.Styles.Frame())
 	}
+	if ic := ui.ROIndicator(x.app.Config.IsReadOnly(), x.app.Config.K9s.UI.NoIcons); ic != "" {
+		title = " " + ic + title
+	}
 
 	buff := x.CmdBuff().GetText()
 	if buff == "" {
